<script setup>
import { ref } from 'vue'

import Card from '~/components/ui/Card.vue'
import Alert from '~/components/ui/Alert.vue'
import Layout from '~/components/ui/Layout.vue'
import Spacer from '~/components/ui/layout/Spacer.vue'
import Tab from '~/components/ui/Tab.vue'
import Tabs from '~/components/ui/Tabs.vue'
import Toggle from '~/components/ui/Toggle.vue'
import Button from '~/components/ui/Button.vue'

const isGrowing = ref(true)
const noGap = ref(true)
</script>

🡔 [Layout](../layout)

# Layout `grid`

Align items both vertically and horizontally.
You can either specify the column width (default: 320px) or set the desired number of columns.

### Override the `:column-width` (in px):

<Layout flex>

```vue-html{1}
<Layout grid :column-width="90"
  :style="`width:${2 * 90 + 32}px`"
>
  <Alert yellow />
  <Card small title="brown" />
  <Alert blue />
</Layout>
```

<Layout grid :column-width="90" class="preview" :style="`width:${2 * 90 + 32}px`">
  <Alert yellow />
  <Card small title="brown" />
  <Alert blue />
</Layout>

</Layout>

### Let elements span multiple rows or columns:

```vue-html{1,2}
  <Alert purple style="grid-column: span 2;" />
  <Card title="2" style="grid-row: span 2;" />
  <Alert green />
  <Card title="1" />
```

<Layout grid>
  <Alert purple style="grid-column: span 2;" />
  <Card title="2" style="grid-row: span 2;" />
  <Alert green />
  <Card title="1" />
</Layout>

### Custom grid configuration

You can pass any valid CSS `grid` value to the `grid` prop:

```vue-html
<Layout grid="auto / repeat(auto-fit, minmax(min-content, 100px))">
  <Alert red />
  <Alert green />
  <Alert blue />
</Layout>
```

<Layout class="preview" grid="auto / repeat(auto-fit, minmax(min-content, 100px))">
  <Alert red />
  <Alert green />
  <Alert blue />
</Layout>
